# eric7.WebBrowser.GreaseMonkey.GreaseMonkeyAddScriptDialog

Module implementing a dialog for adding GreaseMonkey scripts..

### Global Attributes

None

### Classes

GreaseMonkeyAddScriptDialog | Class implementing a dialog for adding GreaseMonkey scripts..

### Functions

None

## GreaseMonkeyAddScriptDialog

Class implementing a dialog for adding GreaseMonkey scripts..

### Derived from

QDialog, Ui_GreaseMonkeyAddScriptDialog

### Class Attributes

None

### Class Methods

None

### Methods

GreaseMonkeyAddScriptDialog | Constructor
__accepted | Private slot handling the accepted signal.
on_showScriptSourceButton_clicked | Private slot to show an editor window with the source code.

### Static Methods

None

#### GreaseMonkeyAddScriptDialog (Constructor)

GreaseMonkeyAddScriptDialog(manager, script, parent=None)

Constructor

manager (GreaseMonkeyManager)
  reference to the GreaseMonkey manager
script (GreaseMonkeyScript)
  GreaseMonkey script to be added
parent (QWidget)
  reference to the parent widget

#### GreaseMonkeyAddScriptDialog.__accepted

__accepted()

Private slot handling the accepted signal.

#### GreaseMonkeyAddScriptDialog.on_showScriptSourceButton_clicked

on_showScriptSourceButton_clicked()

Private slot to show an editor window with the source code.

Up